import setuptools

setuptools.setup(
    name="config_bat",
    version="0.1.0",
    author="Ninh Chu",
    author_email="chulucninh09@gmail.com",
    description="A small example package",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
